/**
 * Define object-structure
 *
 * @param int course_id
 */

function edusharingObject(course_id)
{
	// store object's properties
	this.name = '';
	this.object_url = '';
	this.course = course_id;

	this.mimetype = '';

	this.id = '';
	this.resourcetype = '';
	this.resourceversion = '';

	this.window_width = '';
	this.window_height = '';
	this.frame_border = '';

}




/**
 * Read object-data from node when editor loads content.
 *
 * @param DOMElement node
 *
 * @return bool
 */

edusharingObject.prototype.importNode = function importNode(node){
	var object_url = node.getAttribute('es:object_url');
	if ( ! object_url ) {
		return false;
	}

	this.object_url = object_url;

	var resource_id = node.getAttribute('es:resource_id');
	if ( resource_id ) {
		this.id = resource_id;
	}

	var name = node.getAttribute('alt');
	if ( name ) {
		this.name = name;
	}

	var window_width = node.getAttribute('width');
	if ( window_width ) {
		this.window_width = window_width;
	}

	var window_height = node.getAttribute('height');
	if ( window_height ) {
		this.window_height = window_height;
	}

	var frame_border = node.getAttribute('es:frame_border');
	if ( frame_border ) {
		this.frame_border = frame_border;
	}

	return true;
};








/**
 * Test if
 *
 * @param DOMElement node
 *
 * @return bool
 */
edusharingObject.prototype.changed = function changed(node)
{
	// if width changed we have to save it
	if ( this.window_width != node.getAttribute('width') )
	{
		return true;
	}

	// if height changed we have to save it
	if ( this.window_height != node.getAttribute('height') )
	{
		return true;
	}

	// if title changed we have to save it
	if ( this.name != node.getAttribute('alt') )
	{
		return true;
	}

	return false;
};

/**
 * Link this object.
 *
 * @param tinyMCE editor
 *
 * @return bool
 */
edusharingObject.prototype.link = function link(node, editor, moodle_wwwroot)
{
	// helper-url
	var helper_url = moodle_wwwroot + '/lib/editor/edusharing/helpers/insert.php';

	// bind object for context
	var object = this;

	// post data to ensure usage gets set
    var Y = YUI().use('io', 'json');

	// request-configuration
	var config = {
		// POST data
		method: 'POST',
		// synchronous (blocking) request
		sync	: true,
		// transmit data from form
		data : Y.JSON.stringify(object),
		// default arguments for callbacks
		arguments : {},

		// setup event-handling
		on: {
			/*
			 * request returned successfully
			 *
			 * Parse response. Create new element. Append it.
			 */
			success: function(transId, o, args) {

				try
				{
					var data = Y.JSON.parse(o.responseText);
				}
				catch(exception)
				{
					alert('Invalid server-data received.');
					return false;
				}

				// import received data
				if ( ! data.id ) {
					alert('No resource-id found in data.');
					return false;
				}

				object.id = data.id;

				return true;
			},

			// request failed
			failure: function(transId, o, args) {
				alert('A server-side error occured while linking the object.');
				return false;
			}
		}
    };

	return Y.io(helper_url, config);
};

/**
 * Update this oject properties.
 *
 * @param tinyMCE editor
 * @param string moodle_wwwroot
 *
 * @return bool
 */
edusharingObject.prototype.update = function update(node, editor, moodle_wwwroot)
{
	// update object-properties from node-data
	if ( node.hasAttribute('width') ) {
		this.window_width = node.getAttribute('width');
	}

	if ( node.hasAttribute('height') ) {
		this.window_height = node.getAttribute('height');
	}

	if ( node.hasAttribute('title') ) {
		this.name = node.getAttribute('title');
	}

	// moodle-helper to update object
	var helper_url = moodle_wwwroot + '/lib/editor/edusharing/helpers/update.php';

	// bind object
	var object = this;

	var Y = YUI().use('io', 'json-stringify');

	var config = {
		method	: 'POST',
		// synchronous (blocking) request
		sync	: true,
		headers	: {	'Content-Type': 'application/json'	},
		data	: Y.JSON.stringify(object),

		arguments : {
			object: object
		},

		on: {
			success: function(transId, o, args)
			{
				return true;
			},

			failure: function(transId, o, args)
			{
				alert('An error occured while updating object "' + object.id + '".');
				return false;
			}
		}
	};

	return Y.io(helper_url, config);
};

/**
 * Unlink/delete this object.
 *
 * @param tinyMCE editor
 * @param string moodle_wwwroot
 *
 * @return bool
 */
edusharingObject.prototype.unlink = function unlink(node, editor, moodle_wwwroot)
{
	// tell moodle about deleted object
	var helper_url = moodle_wwwroot + '/lib/editor/edusharing/helpers/delete.php';

	// bind object for context
	var object = this;

	var Y = YUI().use('io', 'json', 'json-stringify');

	var config = {
		method	: 'POST',
		// synchronous (blocking) request
		sync	: true,
		headers	: {	'Content-Type': 'application/json'	},
		data	: Y.JSON.stringify(object),

		arguments : {
			object: object,
			node:	node
		},

		on: {
			success: function(transId, o, args)
			{
				return true;
			},

			failure: function(transId, o, args)
			{
				alert('An error occured while deleting object "' + object.id + '".');
				return false;
			}
		}
	};

	return Y.io(helper_url, config);
};

